@@ -1,7 +1,7 @@
 from pathlib import Path
 from typing import List
 
-from multiversx_sdk_wallet import pem_format
+from multiversx_sdk_wallet.pem_entry import PemEntry
 from multiversx_sdk_wallet.validator_keys import ValidatorSecretKey
 
 
@@ -26,7 +26,7 @@ class ValidatorPEM:
 
     @classmethod
     def from_text_all(cls, text: str) -> List['ValidatorPEM']:
-        entries = pem_format.parse_text(text)
+        entries = PemEntry.from_text_all(text)
         result_items: List[ValidatorPEM] = []
 
         for entry in entries:
@@ -37,5 +37,9 @@ class ValidatorPEM:
         return result_items
 
     def save(self, path: Path):
+        path = path.expanduser().resolve()
+        path.write_text(self.to_text())
+
+    def to_text(self):
         message = self.secret_key.buffer
-        pem_format.write(path, self.label, message)
+        return PemEntry(self.label, message).to_text()
